@@ -3,16 +3,18 @@
 //!
 //! # Example
 //!
-//! ```rust
-//! let wf = debian_watch::WatchFile::new(None);
+//! ```rust,ignore
+//! // For line-based formats (v1-4):
+//! // Note: This example requires the "linebased" feature (enabled by default)
+//! let wf = debian_watch::linebased::WatchFile::new(None);
 //! assert_eq!(wf.version(), debian_watch::DEFAULT_VERSION);
 //! assert_eq!("", wf.to_string());
 //!
-//! let wf = debian_watch::WatchFile::new(Some(4));
+//! let wf = debian_watch::linebased::WatchFile::new(Some(4));
 //! assert_eq!(wf.version(), 4);
 //! assert_eq!("version=4\n", wf.to_string());
 //!
-//! let wf: debian_watch::WatchFile = r#"version=4
+//! let wf: debian_watch::linebased::WatchFile = r#"version=4
 //! opts=foo=blah https://foo.com/bar .*/v?(\d\S+)\.tar\.gz
 //! "#.parse().unwrap();
 //! assert_eq!(wf.version(), 4);
@@ -25,11 +27,18 @@
 //! assert_eq!(entry.matching_pattern().as_deref(), Some(".*/v?(\\d\\S+)\\.tar\\.gz"));
 //! ```
 
+#[cfg(feature = "linebased")]
 mod lex;
-mod parse;
+#[cfg(feature = "linebased")]
+/// Line-based watch file format parser (versions 1-4)
+pub mod linebased;
 
+#[cfg(all(feature = "deb822", feature = "linebased"))]
+mod convert;
 #[cfg(feature = "deb822")]
 pub mod deb822;
+#[cfg(all(feature = "discover", any(feature = "linebased", feature = "deb822")))]
+pub mod discover;
 pub mod mangle;
 #[cfg(feature = "pgp")]
 pub mod pgp;
@@ -40,11 +49,13 @@ pub mod search;
 /// version 1.
 pub const DEFAULT_VERSION: u32 = 1;
 
+#[cfg(any(feature = "linebased", feature = "deb822"))]
+pub mod parse;
+mod subst;
+mod types;
 /// Default user agent string used for HTTP requests
 pub const DEFAULT_USER_AGENT: &str = concat!("debian-watch-rs/", env!("CARGO_PKG_VERSION"));
 
-mod types;
-
 pub use release::Release;
 pub use types::*;
 
@@ -85,21 +96,25 @@ impl From<SyntaxKind> for rowan::SyntaxKind {
     }
 }
 
-pub use crate::parse::Entry;
-pub use crate::parse::EntryBuilder;
-pub use crate::parse::ParseError;
-pub use crate::parse::WatchFile;
+// Only export traits - specific implementations are in their modules
+// Users access linebased types via debian_watch::linebased::WatchFile
+// Users access deb822 types via debian_watch::deb822::WatchFile
 
-#[cfg(test)]
+#[cfg(all(feature = "deb822", feature = "linebased"))]
+pub use crate::convert::{convert_to_v5, ConversionError};
+
+#[cfg(all(test, feature = "linebased"))]
 mod tests {
+    use crate::linebased::WatchFile;
+
     #[test]
     fn test_create_watchfile() {
-        let wf = super::WatchFile::new(None);
+        let wf = WatchFile::new(None);
         assert_eq!(wf.version(), super::DEFAULT_VERSION);
 
         assert_eq!("", wf.to_string());
 
-        let wf = super::WatchFile::new(Some(4));
+        let wf = WatchFile::new(Some(4));
         assert_eq!(wf.version(), 4);
 
         assert_eq!("version=4\n", wf.to_string());
@@ -107,7 +122,7 @@ mod tests {
 
     #[test]
     fn test_set_version() {
-        let mut wf = super::WatchFile::new(Some(4));
+        let mut wf = WatchFile::new(Some(4));
         assert_eq!(wf.version(), 4);
 
         wf.set_version(5);
@@ -115,7 +130,7 @@ mod tests {
         assert_eq!("version=5\n", wf.to_string());
 
         // Test setting version on a file without version
-        let mut wf = super::WatchFile::new(None);
+        let mut wf = WatchFile::new(None);
         assert_eq!(wf.version(), super::DEFAULT_VERSION);
 
         wf.set_version(4);
@@ -126,7 +141,7 @@ mod tests {
     #[test]
     fn test_set_version_on_parsed() {
         // Test that parsed WatchFiles can be mutated
-        let mut wf: super::WatchFile = "version=4\n".parse().unwrap();
+        let mut wf: WatchFile = "version=4\n".parse().unwrap();
         assert_eq!(wf.version(), 4);
 
         wf.set_version(5);
@@ -134,7 +149,7 @@ mod tests {
         assert_eq!("version=5\n", wf.to_string());
 
         // Test setting version on a parsed file without version
-        let mut wf: super::WatchFile = "".parse().unwrap();
+        let mut wf: WatchFile = "".parse().unwrap();
         assert_eq!(wf.version(), super::DEFAULT_VERSION);
 
         wf.set_version(4);
